@@ -48,7 +48,7 @@ class Cart(ModelSQL):
 
     @staticmethod
     def default_user():
-        if not current_user.is_anonymous():
+        if not current_user.is_anonymous:
             return current_user.id
 
     @staticmethod
@@ -342,7 +342,7 @@ class Cart(ModelSQL):
                 flash(message)
                 return redirect(url_for('nereid.cart.view_cart'))
 
-            if not Product(form.product.data).salable:
+            if not Product(form.product.data).template.salable:
                 message = _("This product is not for sale")
                 if request.is_xhr:
                     return jsonify(message=unicode(message)), 400
