@@ -10,22 +10,14 @@
 from datetime import date
 from dateutil.relativedelta import relativedelta
 
-from nereid.helpers import slugify
-from trytond.wizard import StateTransition
 from trytond.transaction import Transaction
 from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
-from trytond.pyson import Bool, Eval
+from trytond.pyson import Bool, Eval, Not
 from nereid import request, cache, jsonify, abort, current_user, route
 from nereid.helpers import key_from_list
-from nereid.contrib.locale import make_lazy_gettext
 
-_ = make_lazy_gettext('nereid_cart_b2c')
-
-__all__ = [
-    'Product', 'AddProductListingStart', 'AddProductListing',
-    'ProductChannelListing',
-]
+__all__ = ['Product']
 __metaclass__ = PoolMeta
 
 
@@ -64,6 +56,13 @@ class Product:
         fields.Boolean("Is Backorder"), getter="get_is_backorder"
     )
 
+    @classmethod
+    def view_attributes(cls):
+        return super(Product, cls).view_attributes() + [
+            ('//page[@id="inventory_det"]', 'states', {
+                'invisible': Not(Bool(Eval('displayed_on_eshop')))
+            })]
+
     def get_is_backorder(self, name):
         if self.min_warehouse_quantity is None or \
                 self.min_warehouse_quantity < 0:
@@ -80,70 +79,6 @@ class Product:
             ),
         })
 
-        # Change displayed_on_eshop to function field
-        cls.displayed_on_eshop = fields.Function(
-            fields.Boolean('Displayed on E-Shop?'),
-            'get_displayed_on_eshop', searcher="search_displayed_on_eshop"
-        )
-
-        cls.uri = fields.Function(
-            fields.Char('URI'), 'get_uri', searcher='search_uri'
-        )
-
-    @classmethod
-    def get_displayed_on_eshop(cls, products, name):
-        Listing = Pool().get('product.product.channel_listing')
-
-        res = {product.id: False for product in products}
-        listings = Listing.search([
-            ('channel.source', '=', 'webshop'),
-            ('state', '=', 'active'),
-            ('channel', '=', Transaction().context.get('current_channel')),
-            ('product', 'in', res.keys())
-        ])
-
-        for listing in listings:
-            res[listing.product.id] = True
-        return res
-
-    @classmethod
-    def search_displayed_on_eshop(cls, name, clause):
-        Listing = Pool().get('product.product.channel_listing')
-
-        listings = Listing.search([
-            ('channel.source', '=', 'webshop'),
-            ('state', '=', 'active'),
-            ('channel', '=', Transaction().context.get('current_channel')),
-        ])
-
-        return [('id', 'in', map(lambda l: l.product.id, listings))]
-
-    @classmethod
-    def get_uri(cls, products, name):
-        Listing = Pool().get('product.product.channel_listing')
-
-        res = {product.id: None for product in products}
-        listings = Listing.search([
-            ('channel.source', '=', 'webshop'),
-            ('channel', '=', Transaction().context.get('current_channel')),
-            ('product', 'in', res.keys())
-        ])
-        for listing in listings:
-            res[listing.product.id] = listing.uri
-        return res
-
-    @classmethod
-    def search_uri(cls, name, clause):
-        Listing = Pool().get('product.product.channel_listing')
-
-        listings = Listing.search([
-            ('channel.source', '=', 'webshop'),
-            ('channel', '=', Transaction().context.get('current_channel')),
-            ('uri', ) + tuple(clause[1:])
-        ])
-
-        return [('id', 'in', map(lambda l: l.product.id, listings))]
-
     @classmethod
     def validate(cls, records):
         """
@@ -176,7 +111,7 @@ class Product:
         """
         Getter for start_displaying_qty_digits
         """
-        return self.default_uom.digits or 2
+        return self.template.default_uom.digits or 2
 
     def can_buy_from_eshop(self):
         """
@@ -220,16 +155,15 @@ class Product:
         the message to show.
         """
         if self.can_buy_from_eshop():
-            status, message = 'in_stock', str(_('In stock'))
+            status, message = 'in_stock', 'In stock'
         else:
-            status, message = 'out_of_stock', str(_('Out of stock'))
+            status, message = 'out_of_stock', 'Out of stock'
 
         quantity = self.get_availability().get('quantity')
 
         if status == 'in_stock' and self.display_available_quantity and \
                 quantity <= self.start_displaying_available_quantity:
-            message = '%s %s %s' % (quantity, self.default_uom.name,
-                                    str(_('left')))
+            message = '%s %s left' % (quantity, self.default_uom.name)
 
         return status, message
 
@@ -269,7 +203,7 @@ class Product:
 
         price_list = Sale.default_price_list()
 
-        if current_user.is_anonymous():
+        if current_user.is_anonymous:
             customer = request.nereid_website.guest_user.party
         else:
             customer = current_user.party
@@ -356,68 +290,3 @@ class Product:
             return abort(404)
 
         return jsonify(product.get_availability())
-
-
-class ProductChannelListing:
-    "Product Sale Channel Listing"
-    __name__ = 'product.product.channel_listing'
-
-    uri = fields.Char(
-        'URI', select=True, states={
-            'required': Eval('channel_source') == 'webshop',
-            'invisible': Eval('channel_source') != 'webshop',
-        }, depends=['channel_source']
-    )
-
-    @fields.depends('product', 'channel', 'uri')
-    def on_change_with_uri(self):
-        """
-        If the URI is empty, slugify template name into URI
-        """
-        if self.uri:
-            return self.uri
-
-        if self.channel and self.channel.source == 'webshop' and self.product:
-            return slugify(self.product.code)
-
-
-class AddProductListingStart:
-    __name__ = 'product.listing.add.start'
-
-    uri = fields.Char(
-        'URI', select=True, states={
-            'required': Eval('channel_source') == 'webshop',
-            'invisible': Eval('channel_source') != 'webshop',
-        }, depends=['channel_source']
-    )
-
-    @fields.depends('product', 'channel', 'uri')
-    def on_change_with_uri(self):
-        """
-        If the URI is empty, slugify template name into URI
-        """
-        if self.uri:
-            return self.uri
-
-        if self.channel and self.channel.source == 'webshop' and self.product:
-            return slugify(self.product.code)
-
-    @classmethod
-    def __setup__(cls):
-        super(AddProductListingStart, cls).__setup__()
-        cls.add_source('webshop')
-
-
-class AddProductListing:
-    __name__ = 'product.listing.add'
-
-    start_webshop = StateTransition()
-
-    def transition_start_webshop(self):
-        Listing = Pool().get('product.product.channel_listing')
-        Listing.create([{
-            'product': self.start.product.id,
-            'channel': self.start.channel.id,
-            'uri': self.start.uri,
-        }])
-        return 'end'
