@@ -9,7 +9,7 @@ import os
 import unittest
 
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import test_view, test_depends
+from trytond.tests.test_tryton import ModuleTestCase
 
 DIR = os.path.abspath(os.path.normpath(os.path.join(
     __file__, '..', '..', '..', '..', '..', 'trytond'
@@ -18,29 +18,12 @@ if os.path.isdir(DIR):
     sys.path.insert(0, os.path.dirname(DIR))
 
 
-class TestViewsDepends(unittest.TestCase):
+class TestViewsDepends(ModuleTestCase):
     '''
     Test views and depends
     '''
 
-    def setUp(self):
-        """
-        Set up data used in the tests.
-        this method is called before each test function execution.
-        """
-        trytond.tests.test_tryton.install_module('nereid_catalog')
-
-    def test0005views(self):
-        '''
-        Test views.
-        '''
-        test_view('nereid_catalog')
-
-    def test0006depends(self):
-        '''
-        Test depends.
-        '''
-        test_depends()
+    module = 'nereid_catalog'
 
 
 def suite():
